<?php

namespace App\Controller\Admin;

use App\Entity\Passager;
use App\Repository\EmployeeRepository;
use Doctrine\ORM\QueryBuilder;
use EasyCorp\Bundle\EasyAdminBundle\Collection\FieldCollection;
use EasyCorp\Bundle\EasyAdminBundle\Collection\FilterCollection;
use EasyCorp\Bundle\EasyAdminBundle\Config\Action;
use EasyCorp\Bundle\EasyAdminBundle\Config\Actions;
use EasyCorp\Bundle\EasyAdminBundle\Config\Crud;
use EasyCorp\Bundle\EasyAdminBundle\Config\Filters;
use EasyCorp\Bundle\EasyAdminBundle\Controller\AbstractCrudController;
use EasyCorp\Bundle\EasyAdminBundle\Dto\EntityDto;
use EasyCorp\Bundle\EasyAdminBundle\Dto\SearchDto;
use EasyCorp\Bundle\EasyAdminBundle\Field\AssociationField;
use EasyCorp\Bundle\EasyAdminBundle\Field\DateField;
use EasyCorp\Bundle\EasyAdminBundle\Field\IdField;
use EasyCorp\Bundle\EasyAdminBundle\Field\TextField;

class PassagerCrudController extends AbstractCrudController
{
    public function __construct(private EmployeeRepository $employeeRepository)
    {
    }
    public static function getEntityFqcn(): string
    {
        return Passager::class;
    }
    public function configureCrud(Crud $crud): Crud
    {
        return $crud
            ->setSearchFields(['lastname','firstname'])
            ->setPageTitle('index', 'Liste des passagers')
            ->setEntityLabelInSingular('ce passager')
            ->setEntityLabelInPlural('passagers')
            ->setDateTimeFormat('dd/MM/yyyy à HH:mm')
            ;
     }

    public function createIndexQueryBuilder(SearchDto $searchDto, EntityDto $entityDto, FieldCollection $fields, FilterCollection $filters): QueryBuilder
    {  
        $user=$this->getUser();
        $companyId = $user->getCompany()->getId();
        $queryBuilder=parent::createIndexQueryBuilder($searchDto, $entityDto, $fields, $filters);
        if (!$this->isGranted('ROLE_SUPER_ADMIN')){
            $queryBuilder->where('entity.company = (:company_0)')
                    ->orderBy('entity.id','DESC')
                    ->setParameter('company_0', $companyId);
        }
        return $queryBuilder;
    }
    public function configureFilters(Filters $filters): Filters
    {
        return $filters
           ->add('booking')
           ->add('company')
        ;
    }
    public function configureFields(string $pageName): iterable
    {
        return [
            AssociationField::new('company'),
            IdField::new('id'),
            AssociationField::new('booking'),
            TextField::new('lastname'),
            TextField::new('firstname'),
            AssociationField::new('employeeEmbarq'),
            DateField::new('embarqDate')->setFormat('dd/MM/yyyy H:i'),
        ];
    }
    
    public function configureActions(Actions $actions): Actions
    {
        return $actions
            ->disable(Action::NEW, Action::EDIT, Action::DELETE);
    }
}
