<?php

namespace App\Controller\Admin;

use App\Entity\Payment;
use App\Repository\EmployeeRepository;
use Doctrine\ORM\QueryBuilder;
use EasyCorp\Bundle\EasyAdminBundle\Collection\FieldCollection;
use EasyCorp\Bundle\EasyAdminBundle\Collection\FilterCollection;
use EasyCorp\Bundle\EasyAdminBundle\Config\Action;
use EasyCorp\Bundle\EasyAdminBundle\Config\Actions;
use EasyCorp\Bundle\EasyAdminBundle\Config\Crud;
use EasyCorp\Bundle\EasyAdminBundle\Config\Filters;
use EasyCorp\Bundle\EasyAdminBundle\Controller\AbstractCrudController;
use EasyCorp\Bundle\EasyAdminBundle\Dto\EntityDto;
use EasyCorp\Bundle\EasyAdminBundle\Dto\SearchDto;
use EasyCorp\Bundle\EasyAdminBundle\Field\AssociationField;
use EasyCorp\Bundle\EasyAdminBundle\Field\DateTimeField;
use EasyCorp\Bundle\EasyAdminBundle\Field\IdField;
use EasyCorp\Bundle\EasyAdminBundle\Field\MoneyField;
use EasyCorp\Bundle\EasyAdminBundle\Field\TextField;

class PaymentCrudController extends AbstractCrudController
{
    public function __construct(private EmployeeRepository $employeeRepository){}
    public static function getEntityFqcn(): string
    {
        return Payment::class;
    }
    public function configureCrud(Crud $crud): Crud
    {
        return $crud
            ->setPageTitle('index', 'Liste des paiements')
            ->setEntityLabelInSingular('ce paiement')
            ->setEntityLabelInPlural('Paiements')
            ->setDateTimeFormat('dd/MM/yyyy à HH:mm')
            ;
     }
    public function configureFields(string $pageName): iterable
    {
        return [
            AssociationField::new('company'),
           // AssociationField::new('customer'), //->setDisabled(true),
           // AssociationField::new('employee')->setQueryBuilder(fn (QueryBuilder $queryBuilder) =>
           //     $queryBuilder->where('entity.company ='.$companyId)),
            AssociationField::new('booking'),
            MoneyField::new('amountPaid')->setCurrency("XAF")
                                        ->setCustomOption('storedAsCents', false)
                                        ->setNumDecimals(0),
            DateTimeField::new('paymentDate')->setFormat('dd/MM/yyyy à HH:mm'),
            TextField::new('paymentMethod'),
            TextField::new('paymentReference')->setDisabled(false),
            //DateTimeField::new('createdAt')->setFormat('dd/MM/yyyy à HH:mm'),
            //DateTimeField::new('updatedAt')->setFormat('dd/MM/yyyy à HH:mm'),
        ];
    }

    public function configureActions(Actions $actions): Actions
    {
    return $actions
        ->disable(Action::NEW, Action::EDIT, Action::DELETE);
    }

    public function createIndexQueryBuilder(SearchDto $searchDto, EntityDto $entityDto, FieldCollection $fields, FilterCollection $filters): QueryBuilder
    {
        $user=$this->getUser();
        $companyId = $user->getCompany()->getId();

        $queryBuilder=parent::createIndexQueryBuilder($searchDto, $entityDto, $fields, $filters);

        if (!$this->isGranted('ROLE_SUPER_ADMIN')){
            $queryBuilder
                        ->where('entity.company = (:company_0)')
                        ->setParameter('company_0', $companyId);
        }

        return $queryBuilder;
    }
    // public function configureFilters(Filters $filters): Filters
    // {
    //     return $filters
    //        ->add('booking')
    //        ->add('company')
    //     ;
    // }
}
