<?php


namespace App\Controller\Admin;

use App\Entity\Company;
use App\Entity\Stopover;
use App\Entity\Schedule;
use App\Entity\Ville;
use App\Repository\EmployeeRepository;
use App\Repository\ScheduleRepository;
use App\Repository\VilleRepository;
use Doctrine\Common\Collections\Criteria;
use Doctrine\ORM\EntityManager;
use Doctrine\ORM\QueryBuilder;
use Doctrine\Persistence\ObjectManager;
use EasyCorp\Bundle\EasyAdminBundle\Collection\FieldCollection;
use EasyCorp\Bundle\EasyAdminBundle\Collection\FilterCollection;
use EasyCorp\Bundle\EasyAdminBundle\Config\Action;
use EasyCorp\Bundle\EasyAdminBundle\Config\Actions;
use EasyCorp\Bundle\EasyAdminBundle\Config\Crud;
use EasyCorp\Bundle\EasyAdminBundle\Config\Filters;
use EasyCorp\Bundle\EasyAdminBundle\Context\AdminContext;
use EasyCorp\Bundle\EasyAdminBundle\Controller\AbstractCrudController;
use EasyCorp\Bundle\EasyAdminBundle\Dto\BatchActionDto;
use EasyCorp\Bundle\EasyAdminBundle\Dto\SearchDto;
use EasyCorp\Bundle\EasyAdminBundle\Dto\EntityDto;
use EasyCorp\Bundle\EasyAdminBundle\Field\AssociationField;
use EasyCorp\Bundle\EasyAdminBundle\Field\BooleanField;
use EasyCorp\Bundle\EasyAdminBundle\Field\CollectionField;
use EasyCorp\Bundle\EasyAdminBundle\Field\CurrencyField;
use EasyCorp\Bundle\EasyAdminBundle\Field\DateField;
use EasyCorp\Bundle\EasyAdminBundle\Field\DateTimeField;
use EasyCorp\Bundle\EasyAdminBundle\Field\IdField;
use EasyCorp\Bundle\EasyAdminBundle\Field\IntegerField;
use EasyCorp\Bundle\EasyAdminBundle\Field\MoneyField;
use EasyCorp\Bundle\EasyAdminBundle\Field\TextField;
use EasyCorp\Bundle\EasyAdminBundle\Field\TimeField;
use Symfony\Component\HttpFoundation\Response;

class ScheduleCrudController extends AbstractCrudController
{

    public function __construct(private EmployeeRepository $employeeRepository){}
    public static function getEntityFqcn(): string
    {
        return Schedule::class;
    }

    public function configureCrud(Crud $crud): Crud
    {
        return $crud
            ->setSearchFields(['scheduleDate'])
            ->setPageTitle('index', 'Liste des trajets')
            ->setEntityLabelInSingular('votre trajet')
            ->setEntityLabelInPlural('Trajets')
            ->setDateTimeFormat('dd/MM/yyyy à HH:mm')
            ;
     }

    
    public function configureFields(string $pageName): iterable
    {
        $user=$this->getUser();
        $companyId = $user->getCompany()->getId();
        if ($this->isGranted('ROLE_SUPER_ADMIN')){
            $disabled=false;
        }else{
            $disabled=true;
        }
        return [
            //IdField::new('id'),
            AssociationField::new('company', 'Compagnie')->setDisabled($disabled),
            AssociationField::new('depart', 'Départ')
                ->setRequired(true)
                ->setQueryBuilder(fn (QueryBuilder $queryBuilder) =>
                $queryBuilder->innerJoin('entity.companyVilles', 'c')
                             ->where('c.company = :company_id')
                             ->orderBy('entity.name','ASC')
                             ->setParameter('company_id', $companyId)  
            ),
            AssociationField::new('arrivee','Destination')
                ->setRequired(true)
                ->setQueryBuilder(fn (QueryBuilder $queryBuilder) =>
                $queryBuilder->innerJoin('entity.companyVilles', 'c')
                             ->where('c.company = :company_id')
                             ->orderBy('entity.name','ASC')
                             ->setParameter('company_id', $companyId)  
            ),
            DateField::new('scheduleDate', 'Date')->setFormat('dd/MM/yyyy'),
            TimeField::new('departureTime', 'Heure départ')->setFormat('HH:mm'),
            TimeField::new('estimatedArrivalTime', 'Heure arrivée')->setFormat('HH:mm'),
            IntegerField::new('seats', 'Places'),
            AssociationField::new('typeTarif')
                ->setRequired(true)
                ->setQueryBuilder(fn (QueryBuilder $queryBuilder) =>
                    $queryBuilder->where('entity.company ='.$companyId)
            ),
            AssociationField::new('bus')
                ->setRequired(true)
                ->setQueryBuilder(fn (QueryBuilder $queryBuilder) =>
                    $queryBuilder->where('entity.company ='.$companyId)
            ),
            BooleanField::new('active', 'Actif'),
            TextField::new('remarks','Message à l\'embarquement'),

            //AssociationField::new('employee','Employé')->setDisabled(true),
            //DateTimeField::new('createdAt')->setFormat('dd/MM/yyyy à HH:mm'),
            //DateTimeField::new('updatedAt')->setFormat('dd/MM/yyyy à HH:mm'),
        ];
    }

    public function createEntity(string $entityFqcn){

        $user=$this->getUser();
        $company = $user->getCompany();
        
        $schedule=new Schedule();
        $schedule->setCompany($company);
        $schedule->setEmployee($user);
        $schedule->setActive(true);
        $schedule->setCreatedAt(new \DateTime());
        $schedule->setUpdatedAt(new \DateTime());
        return $schedule;
    }

    public function createIndexQueryBuilder(SearchDto $searchDto, EntityDto $entityDto, FieldCollection $fields, FilterCollection $filters): QueryBuilder
    {
        $user=$this->getUser();
        
        $queryBuilder=parent::createIndexQueryBuilder($searchDto, $entityDto, $fields, $filters);
        if (!$this->isGranted('ROLE_SUPER_ADMIN')){
            $companyId = $user->getCompany()->getId();
            $queryBuilder->where('entity.company = (:company_0)')
                        ->orderBy('entity.scheduleDate', 'ASC')
                        ->setParameter('company_0', $companyId);                                                                                                                                                                   
            
        }
        return $queryBuilder;
    }

    public function configureActions(Actions $actions ):Actions
    {
        return $actions
            ->add(Crud::PAGE_EDIT, Action::new('duplique', 'Dupliquer tous les 7 jours et 4 fois')
                ->linkToCrudAction('dupliqueSchedule')
                 ->addCssClass('btn btn-primary')
                 ->setIcon('fa fa-users-check')
            );
    }

    public function dupliqueSchedule(AdminContext $context, ScheduleRepository $scheduleRepository)
    {
        $user=$this->getUser();
        $scheduleInstance = $context->getEntity()->getInstance();
        $date = $scheduleInstance->getScheduleDate();
        $frequence = 7;  // en jours
        $nbFois = 4;
        for ($i=0; $i<$nbFois; $i++){
            $newDate = $date;
            date_add($newDate, date_interval_create_from_date_string($frequence." days"));
            $newSchedule = new Schedule;
            $newSchedule->setScheduleDate($newDate);
            $newSchedule->setCompany($scheduleInstance->getCompany());
            $newSchedule->setBus($scheduleInstance->getBus());
            $newSchedule->setSeats($scheduleInstance->getSeats());
            $newSchedule->setActive($scheduleInstance->getActive());
            $newSchedule->setEmployee($user);
            $newSchedule->setDepart($scheduleInstance->getDepart());
            $newSchedule->setDepartureTime($scheduleInstance->getDepartureTime());
            $newSchedule->setArrivee($scheduleInstance->getArrivee());
            $newSchedule->setEstimatedArrivalTime($scheduleInstance->getEstimatedArrivalTime());
            $newSchedule->setRemarks($scheduleInstance->getRemarks());
            $newSchedule->setTypeTarif($scheduleInstance->getTypeTarif());
            $scheduleRepository->save($newSchedule, true);
        }
        return $this->redirect('?crudAction=index&crudControllerFqcn=App%5CController%5CAdmin%5CScheduleCrudController');
    }
    public function configureFilters(Filters $filters): Filters
    {
       if ($this->isGranted('ROLE_SUPER_ADMIN')){
           return $filters
                ->add('company')
                ->add('scheduleDate')
            ;
       }else{
           return $filters
           ;
       }
   }

}
