<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiResource;
use App\Entity\Traits\TimestampsTrait;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;
use App\Repository\BookingRepository;
use Doctrine\ORM\Mapping\HasLifecycleCallbacks;
use Doctrine\Common\Collections\Collection;
use Symfony\Component\Validator\Constraints\Json;
#[ORM\Entity(repositoryClass: BookingRepository::class)]
#[HasLifecycleCallbacks]

class Booking
{
    use TimestampsTrait;
    /**
     * @var int
     */
    #[
        ORM\Column(name: "id", type: Types::INTEGER, nullable: false),
        ORM\Id,
        ORM\GeneratedValue(strategy: "IDENTITY")    
    ]
    private int $id;

    /**
     * @var int
     */
    #[ORM\Column(name: "number_of_seats", type: Types::INTEGER, nullable: false)]
    private int $numberOfSeats;

    /**
     * @var float
     */
    #[ORM\Column(name: "total_amount", type: Types::FLOAT, precision: 10, scale: 0, nullable: false)]
    private float $totalAmount;

    /**
     * @var \DateTime
     */
    #[ORM\Column(name: "date_of_booking", type: Types::DATETIME_MUTABLE, nullable: false)]
    private \DateTime $dateOfBooking;


    /**
     * @var Company
     */
    #[
        ORM\ManyToOne(targetEntity: Company::class),
        ORM\JoinColumn(name: "company_id", referencedColumnName: "id")
    ]
    private Company $company;

    /**
    * @var User
    */
   #[
       ORM\ManyToOne(targetEntity: User::class),
       ORM\JoinColumn(name: "user_id", referencedColumnName: "id")
   ]
   private ?User $user = null;
  
    /**
     * @var Schedule
     */
    #[
        ORM\ManyToOne(targetEntity: Schedule::class),
        ORM\JoinColumn(name: "schedule_id", referencedColumnName: "id")
    ]
    private Schedule $schedule;

 
    #[ORM\OneToMany(mappedBy: 'booking', targetEntity: Passager::class)]
    private Collection $passager;

    #[ORM\Column(nullable: true)]
    private ?array $params = null;

    #[ORM\Column(nullable: true)]
    private ?array $status = null;
    
    public function __construct()
    {
        $this->passager = new ArrayCollection();
    }

    /**
     * @return Collection<int, Passager>
     */
    public function getPassager(): Collection
    {
        return $this->passager;
    }

    public function addPassager(Passager $passager): static
    {
        if (!$this->passager->contains($passager)) {
            $this->passager->add($passager);
            $passager->setBooking($this);
        }

        return $this;
    }

    public function removePassager(Passager $passager): static
    {
        if ($this->passager->removeElement($passager)) {
            // set the owning side to null (unless already changed)
            if ($passager->getBooking() === $this) {
                $passager->setBooking(null);
            }
        }

        return $this;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getNumberOfSeats(): ?int
    {
        return $this->numberOfSeats;
    }

    public function setNumberOfSeats(int $numberOfSeats): self
    {
        $this->numberOfSeats = $numberOfSeats;

        return $this;
    }
    public function getTotalAmount(): ?float
    {
        return $this->totalAmount;
    }

    public function setTotalAmount(float $totalAmount): self
    {
        $this->totalAmount = $totalAmount;

        return $this;
    }

    public function getDateOfBooking(): ?\DateTimeInterface
    {
        return $this->dateOfBooking;
    }

    public function setDateOfBooking(\DateTimeInterface $dateOfBooking): self
    {
        $this->dateOfBooking = $dateOfBooking;

        return $this;
    }

    public function getCompany(): ?Company
    {
        return $this->company;
    }

    public function setCompany(?Company $company): self
    {
        $this->company = $company;

        return $this;
    }

    
    public function getUser(): ?User
    {
        return $this->user;
    }

    public function setUser(?User $user): self
    {
        $this->user = $user;

        return $this;
    }
    public function getSchedule(): ?Schedule
    {
        return $this->schedule;
    }

    public function setSchedule(?Schedule $schedule): self
    {
        $this->schedule = $schedule;

        return $this;
    }
    public function __toString() {
        return $this->getNumdossier();
    }

    public function getParams(): ?array
    {
        return $this->params;
    }

    public function setParams(?array $params): static
    {
        $this->params = $params;

        return $this;
    }

    public function getStatus(): ?array
    {
        return $this->status;
    }

    public function setStatus(?array $status): static
    {
        $this->status = $status;

        return $this;
    }

       /**
     * @var string
     */
    #[ORM\Column(name: "qrcode",type: Types::STRING,  length: 30, nullable: true)]
    private ?string $qrcode;

    #[ORM\Column(length: 30, nullable: true)]
    private ?string $facture = null;

    #[ORM\Column(length: 10)]
    private ?string $numdossier = null;

    #[ORM\ManyToOne(inversedBy: 'bookings')]
    private ?Agence $agenceDepart = null;

    #[ORM\ManyToOne(inversedBy: 'bookings')]
    private ?Agence $agenceArrivee = null;

    public function getQrcode(): ?string
    {
        return $this->qrcode;
    }

    public function setQrcode(string $qrcode): self
    {
        $this->qrcode = $qrcode;

        return $this;
    }

    public function getFacture(): ?string
    {
        return $this->facture;
    }

    public function setFacture(?string $facture): static
    {
        $this->facture = $facture;

        return $this;
    }

    public function getNumdossier(): ?string
    {
        return $this->numdossier;
    }

    public function setNumdossier(string $numdossier): static
    {
        $this->numdossier = $numdossier;

        return $this;
    }

    public function getAgenceDepart(): ?Agence
    {
        return $this->agenceDepart;
    }

    public function setAgenceDepart(?Agence $agenceDepart): static
    {
        $this->agenceDepart = $agenceDepart;

        return $this;
    }

    public function getAgenceArrivee(): ?Agence
    {
        return $this->agenceArrivee;
    }

    public function setAgenceArrivee(?Agence $agenceArrivee): static
    {
        $this->agenceArrivee = $agenceArrivee;

        return $this;
    }

}
