<?php

namespace App\Entity;

use App\Entity\Traits\TimestampsTrait;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;
use App\Repository\BusRepository;
use Doctrine\ORM\Mapping\HasLifecycleCallbacks;


#[ORM\Entity(repositoryClass: BusRepository::class)]
#[HasLifecycleCallbacks]
class Bus
{
    use TimestampsTrait;
    /**
     * @var int
     */
    #[
        ORM\Column(name: "id", type: Types::INTEGER, nullable: false),
        ORM\Id,
        ORM\GeneratedValue(strategy: "IDENTITY")
    ]
    private int $id;

    /**
     * @var string
     */
    #[ORM\Column(name: "bus_plate_number", type: Types::STRING,  length: 15, nullable: false)]
    private string  $busPlateNumber;

    /**
     * @var int
     */
    #[ORM\Column(name: "capacity", type: Types::INTEGER, nullable: false)]
    private int $capacity;

    /**
    * @var Company
    */
   #[
       ORM\ManyToOne(targetEntity: Company::class),
       ORM\JoinColumn(name: "company_id", referencedColumnName: "id", nullable:false)
   ]
   private Company $company;

    /**
     * @var Employee
     */
    #[
        ORM\ManyToOne(targetEntity: Employee::class),
        ORM\JoinColumn(name: "employee_id", referencedColumnName: "id", nullable:false)
    ]
    private Employee $employee;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $image = null;

    #[ORM\ManyToMany(targetEntity: Confort::class, mappedBy: 'bus')]
    private Collection $conforts;

    public function __construct()
    {
        $this->conforts = new ArrayCollection();
    }
 
    public function getId(): ?int
    {
        return $this->id;
    }

    public function getBusPlateNumber(): ?string
    {
        return $this->busPlateNumber;
    }

    public function setBusPlateNumber(string $busPlateNumber): self
    {
        $this->busPlateNumber = $busPlateNumber;

        return $this;
    }

    public function getCapacity(): ?int
    {
        return $this->capacity;
    }

    public function setCapacity(int $capacity): self
    {
        $this->capacity = $capacity;

        return $this;
    }

    
    public function getCompany(): ?Company
    {
        return $this->company;
    }

    public function setCompany(?Company $company): self
    {
        $this->company = $company;

        return $this;
    }


    public function getEmployee(): ?Employee
    {
        return $this->employee;
    }

    public function setEmployee(?Employee $employee): self
    {
        $this->employee = $employee;

        return $this;
    }
    public function __toString() {
        return $this->busPlateNumber;
    }

    public function getImage(): ?string
    {
        return $this->image;
    }

    public function setImage(?string $image): self
    {
        $this->image = $image;

        return $this;
    }

    /**
     * @return Collection<int, Confort>
     */
    public function getConforts(): Collection
    {
        return $this->conforts;
    }

    public function addConfort(Confort $confort): static
    {
        if (!$this->conforts->contains($confort)) {
            $this->conforts->add($confort);
            $confort->addBu($this);
        }

        return $this;
    }

    public function removeConfort(Confort $confort): static
    {
        if ($this->conforts->removeElement($confort)) {
            $confort->removeBu($this);
        }

        return $this;
    }

}
