<?php

namespace App\Entity;

use App\Entity\Traits\TimestampsTrait;
use App\Repository\PassagerRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping\HasLifecycleCallbacks;
use Doctrine\ORM\Mapping as ORM;
use Doctrine\DBAL\Types\Types;

#[ORM\Entity(repositoryClass: PassagerRepository::class)]
#[HasLifecycleCallbacks]
class Passager
{
    use TimestampsTrait;

    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 100)]
    private ?string $firstname = null;
    #[ORM\Column(name: "age", type: Types::INTEGER, nullable: false)]
    private ?int $age = null;

    #[ORM\Column(length: 100)]
    private ?string $lastname = null;

    /**
    * @var Company
    */
    #[
        ORM\ManyToOne(targetEntity: Company::class),
        ORM\JoinColumn(name: "company_id", referencedColumnName: "id")
    ]
    private Company $company;

    public function getCompany(): ?Company
    {
        return $this->company;
    }

    public function setCompany(?Company $company): self
    {
        $this->company = $company;

        return $this;
    }


    #[
        ORM\ManyToOne(targetEntity: Booking::class),
        ORM\JoinColumn(name: "booking_id", referencedColumnName: "id")
    ]
    private Booking $booking;
    private ArrayCollection $bookings;

    #[ORM\Column(type: Types::DATETIME_MUTABLE, nullable: true)]
    private ?\DateTimeInterface $embarqDate = null;

    #[ORM\ManyToOne(inversedBy: 'passagers')]
    private ?Employee $employeeEmbarq = null;


    public function __construct()
    {
        $this->bookings = new ArrayCollection();
    }
    public function getBooking(): ?Booking
    {
        return $this->booking;
    }

    public function setBooking(?Booking $booking): self
    {
        $this->booking = $booking;
        return $this;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getAge(): ?int
    {
        return $this->age;
    }

    public function setAge(int $age): self
    {
        $this->age = $age;
        return $this;
    }

    public function getFirstname(): ?string
    {
        return $this->firstname;
    }

    public function setFirstname(string $firstname): self
    {
        $this->firstname = $firstname;

        return $this;
    }

    public function getLastname(): ?string
    {
        return $this->lastname;
    }

    public function setLastname(string $lastname): self
    {
        $this->lastname = $lastname;

        return $this;
    }
    public function __toString() {
        return $this->lastname. ' '.$this->firstname;
    }
    /**
     * @return Collection<int, Booking>
     */
    public function getBookings(): Collection
    {
        return $this->bookings;
    }

    public function addBooking(Booking $booking): static
    {
        if (!$this->bookings->contains($booking)) {
            $this->bookings->add($booking);
            $booking->addPassager($this);
        }

        return $this;
    }

    public function removeBooking(Booking $booking): static
    {
        if ($this->bookings->removeElement($booking)) {
            $booking->removePassager($this);
        }

        return $this;
    }

    public function getEmbarqDate(): ?\DateTimeInterface
    {
        return $this->embarqDate;
    }

    public function setEmbarqDate(?\DateTimeInterface $embarqDate): static
    {
        $this->embarqDate = $embarqDate;

        return $this;
    }

    public function getEmployeeEmbarq(): ?Employee
    {
        return $this->employeeEmbarq;
    }

    public function setEmployeeEmbarq(?Employee $employeeEmbarq): static
    {
        $this->employeeEmbarq = $employeeEmbarq;

        return $this;
    }

}
