<?php

namespace App\Entity;

use App\Entity\Traits\TimestampsTrait;
use App\Repository\PaymentRepository;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;
use Doctrine\ORM\Mapping\HasLifecycleCallbacks;
use Doctrine\ORM\Mapping\JoinColumn;

#[ORM\Table(name: "payment")]
#[ORM\Entity(repositoryClass: PaymentRepository::class)]
#[HasLifecycleCallbacks]
class Payment
{
    use TimestampsTrait;
    /**
     * @var int
     */
    #[
        ORM\Column(name: "id", type: Types::INTEGER, nullable: false),
        ORM\Id,
        ORM\GeneratedValue(strategy: "IDENTITY")    
    ]
    private int $id;

    /**
     * @var float
     */
    #[ORM\Column(name: "amount_paid", type: Types::FLOAT, precision: 10, scale: 0, nullable: false)]
    private float $amountPaid;

    /**
     * @var \DateTime
     */
    #[ORM\Column(name: "payment_date", type: Types::DATETIME_MUTABLE, nullable: false)]
    private \DateTime $paymentDate;

    /**
     * @var string
     */
    #[ORM\Column(name: "transaction", type: Types::STRING, length: 50, nullable: false)]
    private string $transaction;

    /**
     * @var string
     */
    #[ORM\Column(name: "payment_reference", type: Types::STRING, length: 100, nullable: true)]
    private string $paymentReference;

    #[ORM\OneToOne(cascade: ['persist', 'remove'])]
    private ?Booking $booking = null;

    #[ORM\ManyToOne(inversedBy: 'payments')]
    private ?Company $company = null;
    public function getId(): ?int
    {
        return $this->id;
    }

    public function getAmountPaid(): ?float
    {
        return $this->amountPaid;
    }

    public function setAmountPaid(float $amountPaid): self
    {
        $this->amountPaid = $amountPaid;

        return $this;
    }

    public function getPaymentDate(): ?\DateTimeInterface
    {
        return $this->paymentDate;
    }

    public function setPaymentDate(\DateTimeInterface $paymentDate): self
    {
        $this->paymentDate = $paymentDate;

        return $this;
    }

    public function getTransaction(): ?string
    {
        return $this->transaction;
    }

    public function setTransaction(string $transaction): self
    {
        $this->transaction = $transaction;

        return $this;
    }

    
    public function getPaymentReference(): ?string
    {
        return $this->paymentReference;
    }

    public function setPaymentReference(string $paymentReference): self
    {
        $this->paymentReference = $paymentReference;

        return $this;
    }

    public function __toString() {
        return (string)$this->amountPaid;
    }

    public function getBooking(): ?Booking
    {
        return $this->booking;
    }

    public function setBooking(?Booking $booking): static
    {
        $this->booking = $booking;

        return $this;
    }

    public function getCompany(): ?Company
    {
        return $this->company;
    }

    public function setCompany(?Company $company): static
    {
        $this->company = $company;

        return $this;
    }
}
